@@ -1,16 +1,19 @@
-def dot_product(a, b):
+from typing import List
+
+
+def dot_product(a: List[float], b: List[float]) -> float:
     return sum([x1 * x2 for x1, x2 in zip(a, b)])
 
 
-def frobenius_norm(a):
+def frobenius_norm(a: List[float]) -> float:
     return sum([x * x for x in a]) ** 0.5
 
 
-def cosine_similarity(a, b):
+def cosine_similarity(a: List[float], b: List[float]) -> float:
     return dot_product(a, b) / (frobenius_norm(a) * frobenius_norm(b))
 
 
-def inserting_distance(word1, word2):
+def inserting_distance(word1: str, word2: str) -> int:
     common_start = 0
     for i in range(min(len(word1), len(word2))):
         if word1[i] == word2[i]:
@@ -20,5 +23,5 @@ def inserting_distance(word1, word2):
     return max(len(word1), len(word2)) - common_start
 
 
-def inserting_similarity(word1, word2):
+def inserting_similarity(word1: str, word2: str) -> float:
     return 1.0 - (inserting_distance(word1, word2) / max(len(word1), len(word2)))
